@@ -23,16 +23,15 @@ class CooprInstaller(Installer):
             help='Use one or more packages from the Coin Bazaar software repository.  Multiple packages are specified with a comma-separated list.',
             action='store',
             dest='coin',
-            default='')
+            default=None)
 
     def get_other_packages(self, options):
+        if options.coin is None:
+            return
         for pkg in options.coin.split(','):
             if pkg is '':
                 continue
-            if sys.version_info < (2,6,4):
-                self.add_repository('coopr.'+pkg, root='https://projects.coin-or.org/svn/CoinBazaar/projects/coopr.'+pkg, dev=True, username=os.environ.get('COINOR_USERNAME',None))
-            else:
-                self.add_repository('coopr.'+pkg, root='https://projects.coin-or.org/svn/CoinBazaar/projects/coopr.'+pkg, dev=True, username=os.environ.get('COINOR_USERNAME',None))
+            self.add_repository('coopr.'+pkg, root='https://projects.coin-or.org/svn/CoinBazaar/projects/coopr.'+pkg, dev=True, username=os.environ.get('COINOR_USERNAME',None))
 
     def install_packages(self, options):
         Installer.install_packages(self, options)
